#
# spec file for package coredns-for-k8s1.29
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define project github.com/coredns/coredns
Name:           coredns-for-k8s1.29
Version:        1.11.1
Release:        1.3
Summary:        DNS server written in Go
License:        Apache-2.0
Group:          Productivity/Networking/DNS/Servers
URL:            https://coredns.io
Provides:       dns_daemon
Source0:        coredns-%{version}.tar.gz
Source1:        vendor.tar.gz
Source10:       Corefile
Source11:       coredns.service
BuildRequires:  fdupes
BuildRequires:  golang(API) >= 1.20
Conflicts:      coredns
Provides:       coredns-for-k8s = %{version}
Conflicts:      coredns-for-k8s

%description
CoreDNS is a DNS server in Go. It has a plugin architecture for
extending it.

CoreDNS can listen for DNS request coming in over UDP/TCP (RFC 1035),
TLS (RFC 7858) and gRPC (not a standard).

%package extras
Summary:        Extra components for the coredns package
Group:          Productivity/Networking/DNS/Servers
Requires:       coredns-for-k8s1.29 = %{version}
Supplements:    coredns-for-k8s1.29
BuildArch:      noarch
BuildRequires:  pkgconfig(systemd)
Conflicts:      coredns-extras
Provides:       coredns-extras-for-k8s = %{version}
Conflicts:      coredns-extras-for-k8s

%description extras
Extra components for the coredns package, to make coredns usable in a
non-containerized environment (man pages, configuration, unit file).

%prep
%setup -q -a1 -n coredns-%{version}

%build

# We can't use symlinks here because go-list gets confused by symlinks, so we
# have to copy the source to $HOME/go and then use that as the GOPATH.
export GOPATH=$HOME/go
export PATH=$PATH:$GOPATH/bin
rm -rf $HOME/go/src
mkdir -pv $HOME/go/src/%{project}
find . -mindepth 1 -maxdepth 1 -exec cp -r {} $HOME/go/src/%{project} \;

cd $HOME/go/src/%{project}
go build -mod=vendor -v -buildmode=pie -o coredns

%check
# Too many tests fail due to the restricted permissions in the build enviroment.
# Updates must be tested manually.

%install
cd $HOME/go/src/%{project}

# Binaries
install -D -m 0755 coredns %{buildroot}%{_sbindir}/coredns
ln -s service %{buildroot}%{_sbindir}/rccoredns
# Configuration
install -D -m 0644 %{SOURCE10} %{buildroot}%{_sysconfdir}/coredns/Corefile
# systemd service
install -D -m 0644 %{SOURCE11} %{buildroot}%{_unitdir}/coredns.service
# Manpages
install -d %{buildroot}/%{_mandir}/man1
install -m 0644 man/coredns*.1 %{buildroot}/%{_mandir}/man1
install -d %{buildroot}/%{_mandir}/man5
install -m 0644 man/corefile*.5 %{buildroot}/%{_mandir}/man5
install -d %{buildroot}/%{_mandir}/man7
install -m 0644 man/coredns-*.7 %{buildroot}/%{_mandir}/man7

%fdupes %{buildroot}/%{_prefix}

%pre extras
%service_add_pre coredns.service

%post extras
%service_add_post coredns.service
%{fillup_only -n coredns}

%preun extras
%service_del_preun coredns.service

%postun extras
%service_del_postun coredns.service

%files
# Binaries
%{_sbindir}/coredns
# License
%license LICENSE

%files extras
%{_sbindir}/rccoredns
# Manpages
%{_mandir}/man1/coredns*
%{_mandir}/man5/corefile*
%{_mandir}/man7/coredns-*
# Configs
%dir %{_sysconfdir}/coredns
%config(noreplace) %{_sysconfdir}/coredns/Corefile
%{_unitdir}/coredns.service

%changelog
* Wed Jan 24 2024 Priyanka Saggu <priyanka.saggu@suse.com>
- Update to version 1.11.1:
  * 1.11.1 release: bump version + add notes (#6273)
  * Revert "plugin/forward: Continue waiting after receiving malformed responses (#6014)" (#6270)
  * Plugin dnstap: add support for "extra" field in payload (#6226)
  * build(deps): bump actions/dependency-review-action from 3.0.6 to 3.0.7 (#6269)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.44.317 to 1.44.322 (#6265)
  * build(deps): bump gopkg.in/DataDog/dd-trace-go.v1 from 1.53.0 to 1.54.0 (#6266)
  * build(deps): bump github.com/antonmedv/expr from 1.12.7 to 1.13.0 (#6267)
  * build(deps): bump google.golang.org/api from 0.134.0 to 0.136.0 (#6264)
  * build(deps): bump github.com/openzipkin/zipkin-go from 0.4.1 to 0.4.2 (#6268)
  * fix: remove unnecessary conversion (#6258)
  * Updated go versions used in workflows to 1.21 (#6260)
  * Fix typos (#6235)
  * grep out the timestamp line (#6251)
  * bump quic package to get go 1.21 fix (#6252)
  * fix keepttl parsing (#6250)
  * Fix docker release as mips64le is not avail (#6246)
  * Update release note of 1.11.0 and prepare the release (#6223)
  * build(deps): bump gopkg.in/DataDog/dd-trace-go.v1 from 1.52.0 to 1.53.0 (#6239)
  * build(deps): bump github.com/quic-go/quic-go from 0.35.1 to 0.37.3 (#6238)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.44.312 to 1.44.317 (#6241)
  * build(deps): bump golang.org/x/crypto from 0.11.0 to 0.12.0 (#6242)
  * [RFC-9250]: Add QUIC server support  (#6182)
  * build(deps): bump google.golang.org/grpc from 1.56.2 to 1.57.0 (#6234)
  * update outdated blog links (#6231)
  * build(deps): bump google.golang.org/api from 0.132.0 to 0.134.0 (#6233)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.44.300 to 1.44.312 (#6232)
  * implement Name function on secondary plugin (#6230)
  * build(deps): bump k8s.io/client-go from 0.27.3 to 0.27.4 (#6221)
  * build(deps): bump google.golang.org/api from 0.131.0 to 0.132.0 (#6220)
  * build(deps): bump k8s.io/api from 0.27.3 to 0.27.4 (#6222)
  * build(deps): bump github.com/antonmedv/expr from 1.12.6 to 1.12.7 (#6218)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.44.294 to 1.44.300 (#6209)
  * build(deps): bump github.com/prometheus/client_golang (#6205)
  * build(deps): bump github.com/antonmedv/expr from 1.12.5 to 1.12.6 (#6208)
  * build(deps): bump google.golang.org/api from 0.130.0 to 0.131.0 (#6207)
  * 1.11.0 release prep (#6135)
  * Add GitHub release (#6201)
  * build(deps): bump gopkg.in/DataDog/dd-trace-go.v1 from 1.51.0 to 1.52.0 (#6197)
  * Change default value to 1232 (#6183)
  * Add support for RISC-V (#6195)
  * build(deps): bump google.golang.org/api from 0.129.0 to 0.130.0 (#6199)
  * build(deps): bump github.com/miekg/dns from 1.1.54 to 1.1.55 (#6198)
  * build(deps): bump golang.org/x/crypto from 0.10.0 to 0.11.0 (#6196)
  * build(deps): bump k8s.io/client-go from 0.27.2 to 0.27.3 (#6200)
  * build(deps): bump github.com/oschwald/geoip2-golang from 1.8.0 to 1.9.0 (#6171)
  * build(deps): bump ossf/scorecard-action from 2.1.3 to 2.2.0 (#6180)
  * install faillint properly (#6194)
  * build(deps): bump google.golang.org/api from 0.126.0 to 0.129.0 (#6190)
  * build(deps): bump k8s.io/api from 0.27.2 to 0.27.3 (#6170)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.44.280 to 1.44.294 (#6189)
  * build(deps): bump golang.org/x/crypto from 0.9.0 to 0.10.0 (#6173)
  * Fix forward metrics for backwards compatibility (#6178)
  * fix ports panic (#6179)
  * plugin/kubernetes: filter ExternalName services from matching double subdomain wildcard (#6162)
  * Update workflow versioning (#6165)
  * test: use `t.TempDir` to create temporary test directory (#6164)
  * plugin/kubernetes: Remove Endpoint and EndpointSlice v1beta Support (#6147)
  * build(deps): bump golangci/golangci-lint-action from 3.5.0 to 3.6.0 (#6154)
  * build(deps): bump aquasecurity/trivy-action from 0.10.0 to 0.11.2 (#6155)
  * build(deps): bump github/codeql-action from 2.3.6 to 2.13.4 (#6156)
  * build(deps): bump google.golang.org/api from 0.125.0 to 0.126.0 (#6157)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.44.275 to 1.44.280 (#6158)
  * build(deps): bump github/codeql-action from 2.3.5 to 2.3.6 (#6142)
  * build(deps): bump actions/dependency-review-action from 3.0.4 to 3.0.6 (#6144)
  * replace reviewdog fully by golangci-lint (#6139)
  * plugin/kubernetes: fix headless/endpoint query panics when endpoints are disabled (#6137)
  * build(deps): bump google.golang.org/api from 0.124.0 to 0.125.0 (#6145)
  * build(deps): bump golangci/golangci-lint-action from 3.4.0 to 3.5.0 (#6143)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.44.271 to 1.44.275 (#6146)
  * prevent panics when using DoHWriter (#6120)
  * Revert "plugin/tls: respect the path specified by root plugin (#5944)" (#6136)
  * plugin/tls: respect the path specified by root plugin (#5944)
  * build(deps): bump gopkg.in/DataDog/dd-trace-go.v1 from 1.50.1 to 1.51.0 (#6130)
  * build(deps): bump k8s.io/client-go from 0.27.1 to 0.27.2 (#6129)
  * build(deps): bump github/codeql-action from 2.3.3 to 2.3.5 (#6127)
  * build(deps): bump github.com/prometheus/common from 0.43.0 to 0.44.0 (#6131)
  * build(deps): bump k8s.io/api from 0.27.1 to 0.27.2 (#6132)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.44.266 to 1.44.271 (#6128)
  * build(deps): bump google.golang.org/api from 0.121.0 to 0.124.0 (#6121)
  * Fix: Correct the spelling of committee within the Governance documentation. (#6124)
  * refactor: use standard library instead of `isIn` (#6125)
  * plugin/forward: fix descriptions in README.md (#6123)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.44.245 to 1.44.266 (#6105)
  * Introduces the ARG in Dockerfile   (#5931)
  * build(deps): bump google.golang.org/grpc from 1.54.0 to 1.55.0 (#6098)
  * build(deps): bump go.etcd.io/etcd/client/v3 from 3.5.8 to 3.5.9 (#6096)
  * build(deps): bump actions/setup-go from 4.0.0 to 4.0.1 (#6094)
  * build(deps): bump golang.org/x/crypto from 0.8.0 to 0.9.0 (#6095)
  * build(deps): bump codecov/codecov-action from 3.1.3 to 3.1.4 (#6104)
  * add support unix socket for GRPC (#5943)
  * fuzz: fix forward plugin target (#6115)
  * Update ADOPTERS.md (#6079)
  * build(deps): bump github/codeql-action from 2.3.2 to 2.3.3 (#6080)
  * build(deps): bump github.com/Azure/go-autorest/autorest (#6083)
  * build(deps): bump golang.org/x/sys from 0.7.0 to 0.8.0 (#6084)
  * build(deps): bump github.com/prometheus/common from 0.42.0 to 0.43.0 (#6085)
  * build(deps): bump github.com/miekg/dns from 1.1.53 to 1.1.54 (#6082)
  * build(deps): bump gopkg.in/DataDog/dd-trace-go.v1 from 1.48.0 to 1.50.1 (#6072)
  * build(deps): bump google.golang.org/api from 0.119.0 to 0.121.0 (#6073)
  * Bump golang to 1.20.0 (#6070)
  * build(deps): bump golang.org/x/crypto from 0.7.0 to 0.8.0 (#6064)
  * build(deps): bump github.com/prometheus/client_golang (#6062)
  * build(deps): bump k8s.io/klog/v2 from 2.90.1 to 2.100.1 (#6063)
  * build(deps): bump github/codeql-action from 2.3.0 to 2.3.2 (#6061)
  * Fix temp file close error (#6068)
  * plugin/forward: Continue waiting after receiving malformed responses (#6014)
  * plugin/kubernetes: rename client-go metrics label "url" to "host" (#6040)
  * build(deps): bump google.golang.org/api from 0.114.0 to 0.119.0 (#6045)
  * fix some comments (#6052)
  * Fix typo (#6053)
  * build(deps): bump google.golang.org/grpc from 1.53.0 to 1.54.0 (#6046)
  * build(deps): bump github/codeql-action from 2.2.12 to 2.3.0 (#6044)
  * build(deps): bump aquasecurity/trivy-action from 0.9.2 to 0.10.0 (#6043)
  * build(deps): bump go.etcd.io/etcd/client/v3 from 3.5.7 to 3.5.8 (#6048)
  * build(deps): bump go.etcd.io/etcd/api/v3 from 3.5.7 to 3.5.8 (#6047)
  * build(deps): bump codecov/codecov-action from 3.1.2 to 3.1.3 (#6042)
  * plugin/dnssec: on delegation, sign DS or NSEC of no DS. (#5899)
  * plugin/kubernetes: expose client-go internal request metrics (#5991)
  * update informer for client-go 0.27 (#6038)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.44.224 to 1.44.245 (#6037)
  * build(deps): bump github/codeql-action from 2.2.7 to 2.2.12 (#6030)
  * build(deps): bump codecov/codecov-action from 3.1.1 to 3.1.2 (#6029)
  * build(deps): bump github.com/miekg/dns from 1.1.51 to 1.1.53 (#6011)
  * build(deps): bump github.com/go-logr/logr from 1.2.3 to 1.2.4 (#6010)
  * build(deps): bump github.com/antonmedv/expr from 1.12.1 to 1.12.5 (#6008)
  * build(deps): bump ossf/scorecard-action from 2.1.2 to 2.1.3 (#6006)
  * build(deps): bump actions/stale from 7.0.0 to 8.0.0 (#6005)
  * Prevent fail counter of a proxy overflows (#5990)
  * [rewrite] Introduce cname target rewrite rule to rewrite plugin (#6004)
  * plugin/health: Poll localhost by default (#5934)
  * plugin/forward: Allow Proxy to be used outside of forward plugin. (#5951)
  * plugin/k8s_extenral: Supports fallthrough option (#5959)
  * fix: clouddns plugin answers limited to one response (#5986)
  * build(deps): bump github/codeql-action from 2.2.6 to 2.2.7 (#5978)
  * build(deps): bump actions/setup-go from 3.5.0 to 4.0.0 (#5976)
  * build(deps): bump actions/dependency-review-action from 3.0.3 to 3.0.4 (#5977)
  * build(deps): bump google.golang.org/api from 0.112.0 to 0.114.0 (#5979)
  * build(deps): bump karancode/yamllint-github-action from 2.0.0 to 2.1.1 (#5974)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.44.219 to 1.44.224 (#5982)
  * build(deps): bump k8s.io/api from 0.26.2 to 0.26.3 (#5975)
  * Run coredns as non root. (#5969)
  * Fix trivy scan (#5967)
  * build(deps): bump k8s.io/klog/v2 from 2.90.0 to 2.90.1 (#5966)
  * build(deps): bump k8s.io/client-go from 0.26.1 to 0.26.2 (#5965)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.44.214 to 1.44.219 (#5964)
  * build(deps): bump github/codeql-action from 2.2.5 to 2.2.6 (#5963)
  * build(deps): bump aquasecurity/trivy-action from 0.9.1 to 0.9.2 (#5962)
  * build(deps): bump github.com/prometheus/common from 0.40.0 to 0.42.0 (#5961)
  * build(deps): bump google.golang.org/api from 0.110.0 to 0.112.0 (#5960)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.44.209 to 1.44.214 (#5948)
  * build(deps): bump k8s.io/api from 0.26.1 to 0.26.2 (#5946)
  * build(deps): bump golang.org/x/crypto from 0.6.0 to 0.7.0 (#5950)
  * DoH: Allow http as the protocol (#5762)
  * build(deps): bump github.com/antonmedv/expr from 1.12.0 to 1.12.1 (#5940)
  * build(deps): bump golang.org/x/crypto (#5941)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.44.204 to 1.44.209 (#5939)
  * build(deps): bump github/codeql-action from 2.2.4 to 2.2.5 (#5937)
  * build(deps): bump github.com/miekg/dns from 1.1.50 to 1.1.51 (#5936)
  * build(deps): bump gopkg.in/DataDog/dd-trace-go.v1 from 1.47.0 to 1.48.0 (#5935)
  * build(deps): bump google.golang.org/api from 0.109.0 to 0.110.0 (#5928)
  * dnstap tls support (#5917)
  * build(deps): bump github.com/prometheus/common from 0.39.0 to 0.40.0 (#5926)
  * build(deps): bump golang.org/x/net from 0.5.0 to 0.7.0 (#5929)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.44.199 to 1.44.204 (#5927)
  * send notifies after adding zones all zones (#5774)
  * build: cp Dockerfile in docker-build target (#5925)
  * plugin/loadbalance: Improve weights update (#5906)
  * Close the body after reading the response body information (#5907)
  * build(deps): bump google.golang.org/grpc from 1.52.3 to 1.53.0 (#5922)
  * build(deps): bump golang.org/x/sys from 0.4.0 to 0.5.0 (#5923)
  * build(deps): bump github/codeql-action from 2.2.1 to 2.2.4 (#5920)
  * build(deps): bump aquasecurity/trivy-action from 0.9.0 to 0.9.1 (#5919)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.44.194 to 1.44.199 (#5921)
  * fix typo for log output (#5909)
  * Use http constants instead of string (#5908)
* Wed Jan 24 2024 Priyanka Saggu <priyanka.saggu@suse.com>
- Initial package version 1.11.1
  * Version specified in kubernetes v1.29.1 -  https://github.com/kubernetes/kubernetes/blob/v1.29.1/build/dependencies.yaml#L32
